@@ -5,6 +5,9 @@ as described in `http://lig-membres.imag.fr/termier/HLCM/hlcm.pdf`
 
 # Authors: Rémi Adon <remi.adon@gmail.com>
 #          Luis Galárraga <galarraga@luisgalarraga.de>
+#          Hermann Courteille <hermann.courteille@irisa.fr>
+#          Cyril Regan <cyril.regan@irisa.fr>
+#          Thomas Betton <thomas.betton@irisa.fr>
 #
 # License: BSD 3 clause
 
@@ -15,7 +18,7 @@ import os
 import shutil
 from joblib import Parallel, delayed
 from sortedcontainers import SortedDict
-from roaringbitmap import RoaringBitmap as Bitmap
+from pyroaring import BitMap as Bitmap
 
 from ..utils import _check_min_supp
 from ..utils import filter_maximal
@@ -41,15 +44,9 @@ class LCM(BaseMiner, DiscovererMixin):
         Default to 0.2 (20%)
 
     n_jobs : int, default=1 The number of jobs to use for the computation. Each single item is attributed a job to
-    discover potential itemsets, considering this item as a root in the search space. **Processes are preferred**
-    over threads. **Carefully adjust the number of jobs** otherwise the results may be corrupted especially if you
-    have the following warning: UserWarning: A worker stopped while some jobs were given to the executor.
-
-    max_depth: int, default=-1
-        Maximum depth for exploration in the search space.
-        By default -1 means no limitation in tree recursion.
-        if max_depth >0 is specified, tree exploration is limited to height `max_depth`.
-        A **root node is considered of depth 0**.
+        discover potential itemsets, considering this item as a root in the search space. **Processes are preferred**
+        over threads. **Carefully adjust the number of jobs** otherwise the results may be corrupted especially if you
+        have the following warning: UserWarning: A worker stopped while some jobs were given to the executor.
 
     References
     ----------
@@ -78,10 +75,10 @@ class LCM(BaseMiner, DiscovererMixin):
     >>> patterns[patterns.itemset.map(len) > 3]  # doctest: +SKIP
     """
 
-    def __init__(self, *, min_supp=0.2, n_jobs=1, verbose=False, max_depth=-1):
+    def __init__(self, *, min_supp=0.2, n_jobs=1, verbose=False):
         _check_min_supp(min_supp)
         self.min_supp = min_supp  # cf docstring: minimum support provided by user
-        self.max_depth = int(max_depth)  # cf docstring
+        self.max_length = -1  # maximum length of an itemset
         self.verbose = verbose
         self._min_supp = _check_min_supp(self.min_supp)
         self.item_to_tids = SortedDict()  # Dict : key item ordered by decreasing frequency , value : tids for this
@@ -135,7 +132,7 @@ class LCM(BaseMiner, DiscovererMixin):
 
         return self  # for call .fit().discover() in DiscovererMixin()
 
-    def discover(self, *, return_tids=False, lexicographic_order=False, out=None):
+    def discover(self, *, return_tids=False, lexicographic_order=False, max_length=-1, out=None):
         """Return the set of closed itemsets, with respect to the minimum support
 
         Parameters
@@ -152,6 +149,9 @@ class LCM(BaseMiner, DiscovererMixin):
         lexicographic_order: bool, default=False
             Either the order of the items in each itemset is not ordered or the items are ordered lexicographically
 
+        max_length: int, default=-1 Maximum length of an itemset. By default, -1 means that LCM returns itemsets of
+        all lengths.
+
         out : str, default=None
             File where results are written. Discover return None. The 'out' option is usefull 
             to save memory : Instead of store all branch of lcm-tree in memory , each root 
@@ -169,7 +169,7 @@ class LCM(BaseMiner, DiscovererMixin):
 
             if `return_tids=True` then
                 ==========  =================================
-                itemset     a `list` of co-occured items
+                itemset     a `tuple` of co-occured items
                 support     frequence for this itemset
                 tids        a bitmap tracking positions
                 ==========  =================================
@@ -184,11 +184,12 @@ class LCM(BaseMiner, DiscovererMixin):
         1  [2, 3, 5]       2
         >>> LCM(min_supp=2).fit_discover(D, return_tids=True)
              itemset support       tids
-        0     [2, 5]       3  [0, 1, 2]
-        1  [2, 5, 3]       2     [0, 1]
+        0     [2, 5]       3  (0, 1, 2)
+        1  [2, 5, 3]       2     (0, 1)
         """
         self.lexicographic_order = lexicographic_order
         self.return_tids = return_tids
+        self.max_length = max_length
 
         if out is None:  # store results in memory
             dfs = Parallel(n_jobs=self.n_jobs, prefer="processes")(
@@ -243,10 +244,8 @@ class LCM(BaseMiner, DiscovererMixin):
         else:
             return df
 
-    def _inner(self, p_tids, limit, depth=0):
+    def _inner(self, p_tids, limit):
 
-        if self.max_depth != -1 and depth >= self.max_depth:
-            return None
         p, tids = p_tids
         # project and reduce DB w.r.t P
         cp = (
@@ -265,19 +264,20 @@ class LCM(BaseMiner, DiscovererMixin):
             itemset = [self.ord_item_freq[ind] for ind in list(p_prime)]
             itemset = sorted(itemset) if self.lexicographic_order else itemset
 
-            if not self.return_tids:
-                yield itemset, len(tids)
-            else:
-                yield itemset, len(tids), tids
+            if len(itemset) <= self.max_length or self.max_length == -1:
+                if not self.return_tids:
+                    yield itemset, len(tids)
+                else:
+                    yield itemset, len(tids), tids
 
             candidates = self.item_to_tids.keys() - p_prime
             candidates = candidates[: candidates.bisect_left(limit)]
             for new_limit in candidates:
                 ids = self.item_to_tids[new_limit]
-                if tids.intersection_len(ids) >= self._min_supp:
+                if tids.intersection_cardinality(ids) >= self._min_supp:
                     # new pattern and its associated tids
                     new_p_tids = (p_prime, tids.intersection(ids))
-                    yield from self._inner(new_p_tids, new_limit, depth + 1)
+                    yield from self._inner(new_p_tids, new_limit)
 
     def write_df_tofile(self, filename, df):
         with open(filename, 'w') as fw:  # write the items root files
@@ -305,20 +305,12 @@ class LCMMax(LCM):
         to discover potential itemsets, considering this item as a root in the search space.
         **Processes are preferred** over threads.
 
-    max_depth: int, default=-1
-        Maximum depth for exploration in the search space.
-        By default -1 means no limitation in tree recursion.
-        if max_depth >0 is specified, tree exploration is limited to height `max_depth`.
-        A **root node is considered of depth 0**.
-
     See Also
     --------
     LCM
     """
 
-    def _inner(self, p_tids, limit, depth=0):
-        if self.max_depth != -1 and depth >= self.max_depth:
-            return None
+    def _inner(self, p_tids, limit):
         p, tids = p_tids
         # project and reduce DB w.r.t P
         cp = (
@@ -337,11 +329,11 @@ class LCMMax(LCM):
 
             for new_limit in candidates:
                 ids = self.item_to_tids[new_limit]
-                if tids.intersection_len(ids) >= self._min_supp:
+                if tids.intersection_cardinality(ids) >= self._min_supp:
                     no_cand = False
                     # get new pattern and its associated tids
                     new_p_tids = (p_prime, tids.intersection(ids))
-                    yield from self._inner(new_p_tids, new_limit, depth + 1)
+                    yield from self._inner(new_p_tids, new_limit)
 
             if no_cand:  # only if no child node. This is how we PRE-check for maximality
                 itemset = set([self.ord_item_freq[ind] for ind in p_prime])
@@ -351,12 +343,21 @@ class LCMMax(LCM):
                 else:
                     yield itemset, len(tids), tids
 
-    def discover(self, *args, **kwargs):  # pylint: disable=signature-differs
+    def discover(self, *args, **kwargs):
         outfile = kwargs.get('out')
         kwargs['out'] = None
         patterns = super().discover(**kwargs)
+        # keep only maximal itemsets
         maximals = filter_maximal(patterns["itemset"])
         patterns = patterns[patterns.itemset.isin(maximals)].copy()
+
+        # keeps only itemsets smaller than max_length
+        if self.max_length != -1:
+            length_mask = patterns.itemset.apply(lambda x: len(x) <= self.max_length)
+            patterns = patterns[length_mask]
+            patterns.reset_index(drop=True, inplace=True)
+
+        # return a list of itemset sorted or not
         patterns.loc[:, "itemset"] = patterns["itemset"].map(
             lambda i: sorted(list(i)) if self.lexicographic_order else list(i))
 
