@@ -14,7 +14,7 @@ from typing import List
 import numpy as np
 import pandas as pd
 from sortedcontainers import SortedKeyList
-from roaringbitmap import RoaringBitmap as Bitmap
+from pyroaring import BitMap as Bitmap
 
 from ..base import BaseMiner, DiscovererMixin, InteractiveMiner
 from ..utils import bron_kerbosch
@@ -523,6 +523,8 @@ class PeriodicPatternMiner(BaseMiner, InteractiveMiner, DiscovererMixin):
     """
     Mining Periodic Pattern with a MDL criterion
 
+    Warning: this implementation is unstable.
+
     Implementation of periodic tree mining.
 
     This first extract cycles from the input data, and then combine these cycles
