@@ -3,4 +3,4 @@ The :mod:`skmine.preprocessing` module includes utilities and transformers
 to make the data ingestion easier
 """
 
-from .mdlp_discretizer import MDLPDiscretizer
+from .mdlp_discretizer import MDLPDiscretizer  # noqa
